@@ -127,8 +127,8 @@ class ParallelStoryRunner(StoryRunner):
                 while self.test_queue.unfinished_tasks:
                     time.sleep(1)
             except KeyboardInterrupt:
-                #sys.stderr.write("Parallel tests interrupted by user\n")
-                self.aborted = True
+                self.abort_run()
+                
         finally:
             self.kill_context_queue()
 
@@ -151,24 +151,47 @@ class ParallelStoryRunner(StoryRunner):
                 self.test_queue.put((fixture, scenario))
     
     def fill_context_queue(self, settings):
+        starting_contexts = []
         for i in range(self.number_of_threads):
             context = self.create_context_for(settings)
-            context.browser_driver.start_test()
+
+            #start browser driver in background
+            thread = Thread(target=self.start_context_test, kwargs={'context':context})
+            thread.setDaemon(True)
+            thread.start()
+            starting_contexts.append(thread)
+
             self.available_context_queue.put(i)
             self.contexts.append(context)
-            
-    def kill_context_queue(self):
+        
+        #waiting for threads to finish
+        for thread in starting_contexts:
+            if thread.isAlive():
+                thread.join()
+            else:
+                del(thread)
+
+    def start_context_test(self, context):
+        context.browser_driver.start_test()
+
+    def abort_run(self):
+        self.aborted = True
+        
         for context in self.contexts:
             context.settings.on_scenario_completed = None
     
-        sys.stdout.write("Waiting on child threads... PLEASE DO NOT CANCEL AGAIN!")
-
-        for thread in self.threads:
-            if thread.isAlive():
-                thread.join()
-
-        for context in self.contexts:
-            context.browser_driver.stop_test()
+    def kill_context_queue(self):
+        sys.stdout.write("\nStopping workers, please wait (DO NOT CANCEL AGAIN)...\n")
+        total = len(self.contexts)
+        for index, context in enumerate(self.contexts):
+            percent = (float(index + 1) / total) * 100
+            sys.stdout.write("[%06.2f%%] Stopped worker %d of %d\n" % (percent, index + 1, total))
+            try:
+                context.browser_driver.stop_test()
+            except Exception, e:
+                pass #doesn't matter for the user, the execution MUST be stopped
+                
+        sys.stdout.write("Done.\n")
 
     def worker(self):
         while not self.aborted:
